@@ -10,7 +10,7 @@ class JsonDBInterface(DBInterface, dict):
         self.update(self.__load__(path=path, table_name=table_name))
 
     def dump(self):
-        self.__write__(self.__dict__, self.path, self.table_name)
+        self.__write__(self.copy(), self.path, self.table_name)
 
     def __insert__(self, key, value, e=RuntimeError()):
         if key in self.keys():
